@@ -948,11 +948,10 @@ def sysinfo(args):
     print(f"Hostname:   {result}")
 
     file = "/var/log/kern.log"
-    assert os.path.isfile(file) and os.access(file, os.R_OK), \
-       "File {} doesn't exist or isn't readable".format(file)
-    command = "zgrep DMI: /var/log/kern.log* | grep kernel: | uniq | sed 's|^.*DMI: ||' | head -1"
-    result  = perform.execute(command, getoutput=True, teach=args.teach, noop=args.noop).decode("utf-8").strip()
-    print(f"Computer:   {result}")
+    if os.path.isfile(file) and os.access(file, os.R_OK):
+        command = "zgrep DMI: /var/log/kern.log* | grep kernel: | uniq | sed 's|^.*DMI: ||' | head -1"
+        result  = perform.execute(command, getoutput=True, teach=args.teach, noop=args.noop).decode("utf-8").strip()
+        print(f"Computer:   {result}")
 
     command = "cat /proc/cpuinfo | grep 'name'| uniq | sed 's|^model name	: ||'"
     result  = perform.execute(command, getoutput=True, teach=args.teach, noop=args.noop).decode("utf-8").strip()
